@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, print_function, with_statement
 from typing import Iterable
+from typing import Iterator
 from typing import Union
-from typing import Generator
 
 import os
 import re
@@ -21,10 +21,10 @@ __author__ = u'Juho Vepsäläinen'
 __author_email__ = "bebraw@gmail.com"
 __maintainer__ = u'Jessica Tegner'
 __url__ = 'https://github.com/JessicaTegner/pypandoc'
-__version__ = '1.14'
+__version__ = '1.15'
 __license__ = 'MIT'
 __description__ = "Thin wrapper for pandoc."
-__python_requires__ = ">=3.6"
+__python_requires__ = ">=3.7"
 __setup_requires__ = ['setuptools', 'pip>=8.1.0', 'wheel>=0.25.0']
 __classifiers__ = [
         'Development Status :: 4 - Beta',
@@ -81,6 +81,8 @@ def convert_text(source:str, to:str, format:str, extra_args:Iterable=(), encodin
     :param bool sandbox: Run pandoc in pandocs own sandbox mode, limiting IO operations in readers and writers to reading the files specified on the command line. Anyone using pandoc on untrusted user input should use this option. Note: This only does something, on pandoc >= 2.15
             (Default value = False)
 
+    :param str cworkdir: set the current working directory (Default value = None)
+
     :returns: converted string (unicode) or an empty string if an outputfile was given
     :rtype: unicode
 
@@ -95,10 +97,10 @@ def convert_text(source:str, to:str, format:str, extra_args:Iterable=(), encodin
                           cworkdir=cworkdir)
 
 
-def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:Union[str, None]=None,
+def convert_file(source_file:Union[list, str, Path, Iterator], to:str, format:Union[str, None]=None,
                  extra_args:Iterable=(), encoding:str='utf-8', outputfile:Union[None, str, Path]=None,
                  filters:Union[Iterable, None]=None, verify_format:bool=True, sandbox:bool=False,
-                 cworkdir:Union[str, None]=None) -> str:
+                 cworkdir:Union[str, None]=None, sort_files=True) -> str:
     """Converts given `source` from `format` to `to`.
 
     :param (str, list, pathlib.Path) source_file: If a string, should be either
@@ -131,6 +133,10 @@ def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:U
     :param bool sandbox: Run pandoc in pandocs own sandbox mode, limiting IO operations in readers and writers to reading the files specified on the command line. Anyone using pandoc on untrusted user input should use this option. Note: This only does something, on pandoc >= 2.15
             (Default value = False)
 
+    :param str cworkdir: set the current working directory (Default value = None)
+
+    :param bool sort_files: causes the files to be sorted before being passed to pandoc (Default value = True)
+
     :returns: converted string (unicode) or an empty string if an outputfile was given
     :rtype: unicode
 
@@ -159,7 +165,7 @@ def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:U
         source_file = Path(source_file)
     elif isinstance(source_file, list):
         source_file = [Path(x) for x in source_file]
-    elif isinstance(source_file, Generator):
+    elif isinstance(source_file, Iterator):
         source_file = [Path(x) for x in source_file]
 
 
@@ -169,7 +175,7 @@ def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:U
     # if it is, just use the absolute path
     if isinstance(source_file, list):
         source_file = [x if x.is_absolute() else Path(cworkdir, x) for x in source_file]
-    elif isinstance(source_file, Generator):
+    elif isinstance(source_file, Iterator):
         source_file = (x if x.is_absolute() else Path(cworkdir, x) for x in source_file)
     # check ifjust a single path was given
     elif isinstance(source_file, Path):
@@ -200,7 +206,7 @@ def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:U
     return _convert_input(discovered_source_files, format, 'path', to, extra_args=extra_args,
                       outputfile=outputfile, filters=filters,
                       verify_format=verify_format, sandbox=sandbox,
-                      cworkdir=cworkdir)
+                      cworkdir=cworkdir, sort_files=sort_files)
 
 
 def _identify_path(source) -> bool:
@@ -333,8 +339,7 @@ def _validate_formats(format, to, outputfile):
         )
 
     if base_to_format == "pdf":
-        # pdf formats needs to actually have a to format of latex and a
-        # filename with an ending pf .pdf
+        # pdf formats need a filename with an ending of .pdf
         if isinstance(outputfile, str):
             if outputfile[-4:] != ".pdf":
                 raise RuntimeError(
@@ -345,18 +350,16 @@ def _validate_formats(format, to, outputfile):
                 raise RuntimeError(
                     'PDF output needs an outputfile with ".pdf" as a fileending.'
                 )
-        # to is not allowed to contain pdf, but must point to latex
         # it's also not allowed to contain extensions according to the docs
         if to != base_to_format:
             raise RuntimeError("PDF output can't contain any extensions: %s" % to)
-        to = "latex"
 
     return format, to
 
 
 def _convert_input(source, format, input_type, to, extra_args=(),
                    outputfile=None, filters=None, verify_format=True,
-                   sandbox=False, cworkdir=None):
+                   sandbox=False, cworkdir=None, sort_files=True):
     
     _check_log_handler()
 
@@ -379,8 +382,10 @@ def _convert_input(source, format, input_type, to, extra_args=(),
             input_file = source
     else:
         input_file = []
-    
-    input_file = sorted(input_file)
+
+    if sort_files:
+        input_file = sorted(input_file)
+
     args = [__pandoc_path, '--from=' + format]
 
     args.append('--to=' + to)
